@@ -130,8 +130,8 @@
       cmn = 100.0
       cmx = -100.0
       do 23051 i = 1,nterm 
-      cmn = amin1(cmn,ct(i))
-      cmx = amax1(cmx,ct(i))
+      cmn = min(cmn,ct(i))
+      cmx = max(cmx,ct(i))
 23051 continue
       if(.not.(cmx-cmn.le.delrsq.or.iter.ge.maxit.or.l(pp1).eq.4))goto 2
 &     3053
@@ -239,7 +239,7 @@
 23090 continue
       return
       end
-      block data
+      block data avasdata
       common /parms/ itape,maxit,nterm,span,alpha
       common /spans/ spans(3) /consts/ big,sml,eps
 c------------------------------------------------------------------
@@ -592,7 +592,7 @@ c------------------------------------------------------------------
       sc(j,7)=spans(i)
  80   continue
       if (alpha.gt.0.0.and.alpha.le.10.0.and.resmin.lt.sc(j,6)) sc(j,7)=
-     1sc(j,7)+(spans(3)-sc(j,7))*amax1(sml,resmin/sc(j,6))**(10.0-alpha)
+     1sc(j,7)+(spans(3)-sc(j,7))*max(sml,resmin/sc(j,6))**(10.0-alpha)
  90   continue
       call smooth (n,x,sc(1,7),w,spans(2),-jper,vsmlsq,sc(1,2),h)
       do 110 j=1,n
