@@ -46,7 +46,7 @@ C     MORTRAN 2.79 (RESERVED KEYWORD MACROS OF 09/28/81)
       END                                                                    57 
       SUBROUTINE SMTH(X,Y,W,SPAN,DOF,N,CROSS,SMO,S0,RSS,SCRAT)               58 
       double precision  X(N),Y(N),W(N),SMO(N),SCRAT(N),RSS,SPAN              59 
-      DOUBLE PRECISION*8 SUMW,XBAR,YBAR,COV,VAR                              60 
+      DOUBLE PRECISION SUMW,XBAR,YBAR,COV,VAR                                60 
       INTEGER FIXEDS,CROSS,LINE                                              70 
       LINE=1                                                                 83 
       FIXEDS=1                                                               84 
@@ -150,8 +150,8 @@ C     MORTRAN 2.79 (RESERVED KEYWORD MACROS OF 09/28/81)
 10361 CONTINUE                                                              129 
 10341 CONTINUE                                                              135 
       DO 10371 I=1,N                                                        136 
-      ITNEW=MIN0(I+IS2,N)                                                   136 
-      IBNEW=MAX0(I-IS2,1)                                                   137 
+      ITNEW=MIN(I+IS2,N)                                                    136 
+      IBNEW=MAX(I-IS2,1)                                                    137 
 10381 IF(ITOLD .GE. ITNEW) GOTO 10382                                       137 
       ITOLD=ITOLD+1                                                         137 
       XIN=X(ITOLD)                                                          137 
